@@ -25,12 +25,15 @@ class MainKernelHandler(APIHandler):
 
     @web.authenticated
     @json_errors
+    @gen.coroutine
     def get(self):
         km = self.kernel_manager
-        self.finish(json.dumps(km.list_kernels()))
+        kernels = yield gen.maybe_future(km.list_kernels())
+        self.finish(json.dumps(kernels))
 
     @web.authenticated
     @json_errors
+    @gen.coroutine
     def post(self):
         km = self.kernel_manager
         model = self.get_json_body()
@@ -41,18 +44,16 @@ class MainKernelHandler(APIHandler):
         else:
             model.setdefault('name', km.default_kernel_name)
 
-        kernel_id = km.start_kernel(kernel_name=model['name'])
+        kernel_id = yield gen.maybe_future(km.start_kernel(kernel_name=model['name']))
         model = km.kernel_model(kernel_id)
-        location = url_path_join(self.base_url, 'api', 'kernels', kernel_id)
-        self.set_header('Location', url_escape(location))
+        location = url_path_join(self.base_url, 'api', 'kernels', url_escape(kernel_id))
+        self.set_header('Location', location)
         self.set_status(201)
         self.finish(json.dumps(model))
 
 
 class KernelHandler(APIHandler):
 
-    SUPPORTED_METHODS = ('DELETE', 'GET', 'OPTIONS')
-
     @web.authenticated
     @json_errors
     def get(self, kernel_id):
@@ -63,39 +64,34 @@ class KernelHandler(APIHandler):
 
     @web.authenticated
     @json_errors
+    @gen.coroutine
     def delete(self, kernel_id):
         km = self.kernel_manager
-        km.shutdown_kernel(kernel_id)
+        yield gen.maybe_future(km.shutdown_kernel(kernel_id))
         self.set_status(204)
         self.finish()
 
-    @web.authenticated
-    @json_errors
-    def options(self, kernel_id):
-        self.set_header('Access-Control-Allow-Headers', 'accept, content-type')
-        self.finish()
-
 
 class KernelActionHandler(APIHandler):
 
     @web.authenticated
     @json_errors
+    @gen.coroutine
     def post(self, kernel_id, action):
         km = self.kernel_manager
         if action == 'interrupt':
             km.interrupt_kernel(kernel_id)
             self.set_status(204)
         if action == 'restart':
-            km.restart_kernel(kernel_id)
-            model = km.kernel_model(kernel_id)
-            self.set_header('Location', '{0}api/kernels/{1}'.format(self.base_url, kernel_id))
-            self.write(json.dumps(model))
-        self.finish()
 
-    @web.authenticated
-    @json_errors
-    def options(self, kernel_id, action):
-        self.set_header('Access-Control-Allow-Headers', 'accept, content-type')
+            try:
+                yield gen.maybe_future(km.restart_kernel(kernel_id))
+            except Exception as e:
+                self.log.error("Exception restarting kernel", exc_info=True)
+                self.set_status(500)
+            else:
+                model = km.kernel_model(kernel_id)
+                self.write(json.dumps(model))
         self.finish()
 
 
